// Generated file. To retain edits, remove this comment.
import { InterfaceTypes, runPipeline } from 'itk-wasm';
import { getPipelinesBaseUrl } from './pipelines-base-url.js';
import { getPipelineWorkerUrl } from './pipeline-worker-url.js';
import { getDefaultWebWorker } from './default-web-worker.js';
/**
 * Read a point set file format and convert it to the itk-wasm file format
 *
 * @param {File | BinaryFile} serializedPointSet - Input point set serialized in the file format
 * @param {VtkPolyDataReadPointSetOptions} options - options object
 *
 * @returns {Promise<VtkPolyDataReadPointSetResult>} - result object
 */
async function vtkPolyDataReadPointSet(serializedPointSet, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.PointSet },
    ];
    let serializedPointSetFile = serializedPointSet;
    if (serializedPointSet instanceof File) {
        const serializedPointSetBuffer = await serializedPointSet.arrayBuffer();
        serializedPointSetFile = { path: serializedPointSet.name, data: new Uint8Array(serializedPointSetBuffer) };
    }
    const inputs = [
        { type: InterfaceTypes.BinaryFile, data: serializedPointSetFile },
    ];
    const args = [];
    // Inputs
    const serializedPointSetName = serializedPointSetFile.path;
    args.push(serializedPointSetName);
    // Outputs
    const couldReadName = '0';
    args.push(couldReadName);
    const pointSetName = '1';
    args.push(pointSetName);
    // Options
    args.push('--memory-io');
    if (options.informationOnly) {
        options.informationOnly && args.push('--information-only');
    }
    const pipelinePath = 'vtk-poly-data-read-point-set';
    let workerToUse = options?.webWorker;
    if (workerToUse === undefined) {
        workerToUse = await getDefaultWebWorker();
    }
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl(), pipelineWorkerUrl: getPipelineWorkerUrl(), webWorker: workerToUse, noCopy: options?.noCopy });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldRead: outputs[0]?.data,
        pointSet: outputs[1]?.data,
    };
    return result;
}
export default vtkPolyDataReadPointSet;
//# sourceMappingURL=vtk-poly-data-read-point-set.js.map