import path from "path";
import { getFileExtension } from "itk-wasm";
import mimeToMeshIo from "./mime-to-mesh-io.js";
import extensionToMeshIo from "./extension-to-mesh-io.js";
import meshIoIndexNode from "./mesh-io-index-node.js";
/**
 * Write a mesh to a serialized file format and from an the itk-wasm Mesh
 *
 * @param {Mesh} mesh - Input mesh
 * @param {string} serializedMesh - Output mesh serialized in the file format.
 * @param {WriteMeshOptions} options - options object
 *
 * @returns {void} - result object
 */
async function writeMeshNode(mesh, serializedMesh, options = {}) {
    const absoluteFilePath = path.resolve(serializedMesh);
    const mimeType = options.mimeType;
    const extension = getFileExtension(absoluteFilePath);
    let inputMesh = mesh;
    let io = null;
    if (typeof mimeType !== "undefined" && mimeToMeshIo.has(mimeType)) {
        io = mimeToMeshIo.get(mimeType);
    }
    else if (extensionToMeshIo.has(extension)) {
        io = extensionToMeshIo.get(extension);
    }
    else {
        for (const readerWriter of meshIoIndexNode.values()) {
            if (readerWriter[1] !== null) {
                let { couldWrite } = await readerWriter[1](inputMesh, absoluteFilePath, {
                    useCompression: options.useCompression,
                    binaryFileType: options.binaryFileType,
                });
                if (couldWrite) {
                    return;
                }
            }
        }
    }
    if (io === null) {
        throw Error("Could not find IO for: " + absoluteFilePath);
    }
    const readerWriter = meshIoIndexNode.get(io);
    const writer = readerWriter[1];
    let { couldWrite } = await writer(inputMesh, absoluteFilePath, {
        useCompression: options.useCompression,
    });
    if (!couldWrite) {
        throw Error("Could not write: " + absoluteFilePath);
    }
}
export default writeMeshNode;
//# sourceMappingURL=write-mesh-node.js.map