import { getFileExtension, } from 'itk-wasm';
import mimeToMeshIo from './mime-to-mesh-io.js';
import extensionToMeshIo from './extension-to-mesh-io.js';
import meshIoIndex from './mesh-io-index.js';
/**
 * Write an itk-wasm Mesh converted to an serialized mesh file format
 *
 * @param {Mesh} mesh - Input mesh
 * @param {string} serializedMesh - Output mesh serialized in the file format.
 * @param {WriteMeshOptions} options - options object
 *
 * @returns {Promise<WriteMeshResult>} - result object
 */
async function writeMesh(mesh, serializedMesh, options = {}) {
    let inputMesh = mesh;
    const mimeType = options.mimeType;
    const extension = getFileExtension(serializedMesh).toLowerCase();
    let usedWebWorker = options.webWorker;
    let io = null;
    if (typeof mimeType !== 'undefined' && mimeToMeshIo.has(mimeType)) {
        io = mimeToMeshIo.get(mimeType);
    }
    else if (extensionToMeshIo.has(extension)) {
        io = extensionToMeshIo.get(extension);
    }
    else {
        for (const readerWriter of meshIoIndex.values()) {
            if (readerWriter[1] !== null) {
                let { webWorker: testWebWorker, couldWrite, serializedMesh: serializedMeshBuffer } = await readerWriter[1](inputMesh, serializedMesh, options);
                usedWebWorker = testWebWorker;
                if (couldWrite) {
                    return { webWorker: usedWebWorker, serializedMesh: serializedMeshBuffer };
                }
            }
        }
    }
    if (!io) {
        throw Error('Could not find IO for: ' + serializedMesh);
    }
    const readerWriter = meshIoIndex.get(io);
    const writer = readerWriter[1];
    let { webWorker: testWebWorker, couldWrite, serializedMesh: serializedMeshBuffer } = await writer(inputMesh, serializedMesh, options);
    usedWebWorker = testWebWorker;
    if (!couldWrite) {
        throw Error('Could not write: ' + serializedMesh);
    }
    const result = {
        webWorker: usedWebWorker,
        serializedMesh: serializedMeshBuffer
    };
    return result;
}
export default writeMesh;
//# sourceMappingURL=write-mesh.js.map